You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2010/06/15 23:15:06 UTC

svn commit: r955056 [3/5] - in /directory: apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/ apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/event/ apacheds/trunk/core-api/src/main/java/org/apache/directory/...

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultCoreSession.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultCoreSession.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultCoreSession.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultCoreSession.java Tue Jun 15 21:15:04 2010
@@ -136,12 +136,12 @@ public class DefaultCoreSession implemen
      */
     public void add( Entry entry, LogChange log ) throws LdapException
     {
-        AddOperationContext opContext = new AddOperationContext( this, entry );
+        AddOperationContext addContext = new AddOperationContext( this, entry );
 
-        opContext.setLogChange( log );
+        addContext.setLogChange( log );
         
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.add( opContext );
+        operationManager.add( addContext );
     }
 
 
@@ -150,13 +150,13 @@ public class DefaultCoreSession implemen
      */
     public void add( Entry entry, boolean ignoreReferral, LogChange log ) throws LdapException
     {
-        AddOperationContext opContext = new AddOperationContext( this, entry );
+        AddOperationContext addContext = new AddOperationContext( this, entry );
 
-        opContext.setLogChange( log );
-        setReferralHandling( opContext, ignoreReferral );
+        addContext.setLogChange( log );
+        setReferralHandling( addContext, ignoreReferral );
         
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.add( opContext );
+        operationManager.add( addContext );
     }
 
 
@@ -174,13 +174,13 @@ public class DefaultCoreSession implemen
      */
     public void add( InternalAddRequest addRequest, LogChange log ) throws LdapException
     {
-        AddOperationContext opContext = new AddOperationContext( this, addRequest );
+        AddOperationContext addContext = new AddOperationContext( this, addRequest );
 
-        opContext.setLogChange( log );
+        addContext.setLogChange( log );
         
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.add( opContext );
-        addRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.add( addContext );
+        addRequest.getResultResponse().addAll( addContext.getResponseControls() );
     }
 
     
@@ -243,14 +243,14 @@ public class DefaultCoreSession implemen
      */
     public boolean compare( DN dn, String oid, Object value, boolean ignoreReferral ) throws LdapException
     {
-        CompareOperationContext opContext =  
+        CompareOperationContext compareContext =  
                 new CompareOperationContext( this, dn, oid, 
                     convertToValue( oid, value ) );
         
-        setReferralHandling( opContext, ignoreReferral );
+        setReferralHandling( compareContext, ignoreReferral );
         
         OperationManager operationManager = directoryService.getOperationManager();
-        return operationManager.compare( opContext );
+        return operationManager.compare( compareContext );
     }
 
 
@@ -268,12 +268,12 @@ public class DefaultCoreSession implemen
      */
     public void delete( DN dn, LogChange log ) throws LdapException
     {
-        DeleteOperationContext opContext = new DeleteOperationContext( this, dn );
+        DeleteOperationContext deleteContext = new DeleteOperationContext( this, dn );
 
-        opContext.setLogChange( log );
+        deleteContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.delete( opContext );
+        operationManager.delete( deleteContext );
     }
 
 
@@ -291,13 +291,13 @@ public class DefaultCoreSession implemen
      */
     public void delete( DN dn, boolean ignoreReferral, LogChange log ) throws LdapException
     {
-        DeleteOperationContext opContext = new DeleteOperationContext( this, dn );
+        DeleteOperationContext deleteContext = new DeleteOperationContext( this, dn );
         
-        opContext.setLogChange( log );
-        setReferralHandling( opContext, ignoreReferral );
+        deleteContext.setLogChange( log );
+        setReferralHandling( deleteContext, ignoreReferral );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.delete( opContext );
+        operationManager.delete( deleteContext );
     }
 
 
@@ -445,10 +445,10 @@ public class DefaultCoreSession implemen
     {
         OperationManager operationManager = directoryService.getOperationManager();
 
-        ListOperationContext listOperationContext = new ListOperationContext( this, dn, returningAttributes );
-        listOperationContext.setAliasDerefMode( aliasDerefMode );
+        ListOperationContext listContext = new ListOperationContext( this, dn, returningAttributes );
+        listContext.setAliasDerefMode( aliasDerefMode );
         
-        return operationManager.list( listOperationContext );
+        return operationManager.list( listContext );
     }
 
 
@@ -460,12 +460,12 @@ public class DefaultCoreSession implemen
     {
         OperationManager operationManager = directoryService.getOperationManager();
 
-        ListOperationContext listOperationContext = new ListOperationContext( this, dn, returningAttributes );
-        listOperationContext.setSizeLimit( sizeLimit );
-        listOperationContext.setTimeLimit( timeLimit );
-        listOperationContext.setAliasDerefMode( aliasDerefMode );
+        ListOperationContext listContext = new ListOperationContext( this, dn, returningAttributes );
+        listContext.setSizeLimit( sizeLimit );
+        listContext.setTimeLimit( timeLimit );
+        listContext.setAliasDerefMode( aliasDerefMode );
         
-        return operationManager.list( listOperationContext );
+        return operationManager.list( listContext );
     }
 
 
@@ -485,9 +485,9 @@ public class DefaultCoreSession implemen
     public Entry lookup( DN dn, String[] attrId ) throws LdapException
     {
         OperationManager operationManager = directoryService.getOperationManager();
-        LookupOperationContext lookupOperationContext = new LookupOperationContext( this, dn, attrId );
+        LookupOperationContext lookupContext = new LookupOperationContext( this, dn, attrId );
 
-        Entry entry = operationManager.lookup( lookupOperationContext );
+        Entry entry = operationManager.lookup( lookupContext );
         
         return entry;
     }
@@ -519,12 +519,12 @@ public class DefaultCoreSession implemen
             serverModifications.add( new DefaultModification( directoryService.getSchemaManager(), mod ) );
         }
         
-        ModifyOperationContext opContext = new ModifyOperationContext( this, dn, serverModifications );
+        ModifyOperationContext modifyContext = new ModifyOperationContext( this, dn, serverModifications );
 
-        opContext.setLogChange( log );
+        modifyContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.modify( opContext );
+        operationManager.modify( modifyContext );
     }
 
 
@@ -554,13 +554,13 @@ public class DefaultCoreSession implemen
             serverModifications.add( new DefaultModification( directoryService.getSchemaManager(), mod ) );
         }
 
-        ModifyOperationContext opContext = new ModifyOperationContext( this, dn, serverModifications );
+        ModifyOperationContext modifyContext = new ModifyOperationContext( this, dn, serverModifications );
         
-        setReferralHandling( opContext, ignoreReferral );
-        opContext.setLogChange( log );
+        setReferralHandling( modifyContext, ignoreReferral );
+        modifyContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.modify( opContext );
+        operationManager.modify( modifyContext );
     }
 
 
@@ -578,11 +578,11 @@ public class DefaultCoreSession implemen
      */
     public void move( DN dn, DN newParent, LogChange log ) throws LdapException
     {
-        MoveOperationContext opContext = new MoveOperationContext( this, dn, newParent );
-        opContext.setLogChange( log );
+        MoveOperationContext moveContext = new MoveOperationContext( this, dn, newParent );
+        moveContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.move( opContext );
+        operationManager.move( moveContext );
     }
 
 
@@ -601,12 +601,12 @@ public class DefaultCoreSession implemen
     public void move( DN dn, DN newParent, boolean ignoreReferral, LogChange log ) throws LdapException
     {
         OperationManager operationManager = directoryService.getOperationManager();
-        MoveOperationContext opContext = new MoveOperationContext( this, dn, newParent );
+        MoveOperationContext moveContext = new MoveOperationContext( this, dn, newParent );
         
-        setReferralHandling( opContext, ignoreReferral );
-        opContext.setLogChange( log );
+        setReferralHandling( moveContext, ignoreReferral );
+        moveContext.setLogChange( log );
 
-        operationManager.move( opContext );
+        operationManager.move( moveContext );
     }
 
 
@@ -624,13 +624,13 @@ public class DefaultCoreSession implemen
      */
     public void moveAndRename( DN dn, DN newSuperiorDn, RDN newRdn, boolean deleteOldRdn, LogChange log ) throws LdapException
     {
-        MoveAndRenameOperationContext opContext = 
+        MoveAndRenameOperationContext moveAndRenameContext = 
             new MoveAndRenameOperationContext( this, dn, newSuperiorDn, newRdn, deleteOldRdn );
         
-        opContext.setLogChange( log );
+        moveAndRenameContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.moveAndRename( opContext );
+        operationManager.moveAndRename( moveAndRenameContext );
     }
 
 
@@ -649,12 +649,12 @@ public class DefaultCoreSession implemen
     public void moveAndRename( DN dn, DN newParent, RDN newRdn, boolean deleteOldRdn, boolean ignoreReferral, LogChange log ) throws LdapException
     {
         OperationManager operationManager = directoryService.getOperationManager();
-        MoveAndRenameOperationContext opContext = new MoveAndRenameOperationContext( this, dn, newParent, newRdn, deleteOldRdn );
+        MoveAndRenameOperationContext moveAndRenameContext = new MoveAndRenameOperationContext( this, dn, newParent, newRdn, deleteOldRdn );
         
-        opContext.setLogChange( log );
-        setReferralHandling( opContext, ignoreReferral );
+        moveAndRenameContext.setLogChange( log );
+        setReferralHandling( moveAndRenameContext, ignoreReferral );
 
-        operationManager.moveAndRename( opContext );
+        operationManager.moveAndRename( moveAndRenameContext );
     }
 
 
@@ -672,13 +672,13 @@ public class DefaultCoreSession implemen
      */
     public void rename( DN dn, RDN newRdn, boolean deleteOldRdn, LogChange log ) throws LdapException
     {
-        RenameOperationContext opContext = new RenameOperationContext( this, dn, newRdn, deleteOldRdn );
+        RenameOperationContext renameContext = new RenameOperationContext( this, dn, newRdn, deleteOldRdn );
         
-        opContext.setLogChange( log );
+        renameContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
         
-        operationManager.rename( opContext );
+        operationManager.rename( renameContext );
     }
 
 
@@ -697,12 +697,12 @@ public class DefaultCoreSession implemen
     public void rename( DN dn, RDN newRdn, boolean deleteOldRdn, boolean ignoreReferral, LogChange log ) throws LdapException
     {
         OperationManager operationManager = directoryService.getOperationManager();
-        RenameOperationContext opContext = new RenameOperationContext( this, dn, newRdn, deleteOldRdn );
+        RenameOperationContext renameContext = new RenameOperationContext( this, dn, newRdn, deleteOldRdn );
         
-        opContext.setLogChange( log );
-        setReferralHandling( opContext, ignoreReferral );
+        renameContext.setLogChange( log );
+        setReferralHandling( renameContext, ignoreReferral );
 
-        operationManager.rename( opContext );
+        operationManager.rename( renameContext );
     }
 
 
@@ -732,12 +732,12 @@ public class DefaultCoreSession implemen
             throw new LdapInvalidSearchFilterException( pe.getMessage() );
         }
         
-        SearchOperationContext searchOperationContext = new SearchOperationContext( this, dn, SearchScope.OBJECT, 
+        SearchOperationContext searchContext = new SearchOperationContext( this, dn, SearchScope.OBJECT, 
             filterNode, null );
-        searchOperationContext.setAliasDerefMode( AliasDerefMode.DEREF_ALWAYS ); 
-        setReferralHandling( searchOperationContext, ignoreReferrals );
+        searchContext.setAliasDerefMode( AliasDerefMode.DEREF_ALWAYS ); 
+        setReferralHandling( searchContext, ignoreReferrals );
 
-        return operationManager.search( searchOperationContext );
+        return operationManager.search( searchContext );
     }
     
 
@@ -749,11 +749,11 @@ public class DefaultCoreSession implemen
     {
         OperationManager operationManager = directoryService.getOperationManager();
 
-        SearchOperationContext searchOperationContext = new SearchOperationContext( this, dn, scope, filter, 
+        SearchOperationContext searchContext = new SearchOperationContext( this, dn, scope, filter, 
             returningAttributes );
-        searchOperationContext.setAliasDerefMode( aliasDerefMode );
+        searchContext.setAliasDerefMode( aliasDerefMode );
 
-        return operationManager.search( searchOperationContext );
+        return operationManager.search( searchContext );
     }
 
 
@@ -765,13 +765,13 @@ public class DefaultCoreSession implemen
     {
         OperationManager operationManager = directoryService.getOperationManager();
 
-        SearchOperationContext searchOperationContext = new SearchOperationContext( this, dn, scope, filter, 
+        SearchOperationContext searchContext = new SearchOperationContext( this, dn, scope, filter, 
             returningAttributes );
-        searchOperationContext.setAliasDerefMode( aliasDerefMode );
-        searchOperationContext.setSizeLimit( sizeLimit );
-        searchOperationContext.setTimeLimit( timeLimit );
+        searchContext.setAliasDerefMode( aliasDerefMode );
+        searchContext.setSizeLimit( sizeLimit );
+        searchContext.setTimeLimit( timeLimit );
         
-        return operationManager.search( searchOperationContext );
+        return operationManager.search( searchContext );
     }
 
 
@@ -786,10 +786,10 @@ public class DefaultCoreSession implemen
      */
     public boolean compare( InternalCompareRequest compareRequest ) throws LdapException
     {
-        CompareOperationContext opContext = new CompareOperationContext( this, compareRequest );
+        CompareOperationContext compareContext = new CompareOperationContext( this, compareRequest );
         OperationManager operationManager = directoryService.getOperationManager();
-        boolean result = operationManager.compare( opContext );
-        compareRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        boolean result = operationManager.compare( compareContext );
+        compareRequest.getResultResponse().addAll( compareContext.getResponseControls() );
         return result;
     }
 
@@ -808,21 +808,21 @@ public class DefaultCoreSession implemen
      */
     public void delete( InternalDeleteRequest deleteRequest, LogChange log ) throws LdapException
     {
-        DeleteOperationContext opContext = new DeleteOperationContext( this, deleteRequest );
+        DeleteOperationContext deleteContext = new DeleteOperationContext( this, deleteRequest );
         
-        opContext.setLogChange( log );
+        deleteContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.delete( opContext );
-        deleteRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.delete( deleteContext );
+        deleteRequest.getResultResponse().addAll( deleteContext.getResponseControls() );
     }
 
 
     public boolean exists( DN dn ) throws LdapException
     {
-        EntryOperationContext opContext = new EntryOperationContext( this, dn );
+        EntryOperationContext hasEntryContext = new EntryOperationContext( this, dn );
         OperationManager operationManager = directoryService.getOperationManager();
-        return operationManager.hasEntry( opContext );
+        return operationManager.hasEntry( hasEntryContext );
     }
 
 
@@ -840,13 +840,13 @@ public class DefaultCoreSession implemen
      */
     public void modify( InternalModifyRequest modifyRequest, LogChange log ) throws LdapException
     {
-        ModifyOperationContext opContext = new ModifyOperationContext( this, modifyRequest );
+        ModifyOperationContext modifyContext = new ModifyOperationContext( this, modifyRequest );
 
-        opContext.setLogChange( log );
+        modifyContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.modify( opContext );
-        modifyRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.modify( modifyContext );
+        modifyRequest.getResultResponse().addAll( modifyContext.getResponseControls() );
     }
 
 
@@ -864,13 +864,13 @@ public class DefaultCoreSession implemen
      */
     public void move( InternalModifyDnRequest modifyDnRequest, LogChange log ) throws LdapException
     {
-        MoveOperationContext opContext = new MoveOperationContext( this, modifyDnRequest );
+        MoveOperationContext moveContext = new MoveOperationContext( this, modifyDnRequest );
         
-        opContext.setLogChange( log );
+        moveContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.move( opContext );
-        modifyDnRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.move( moveContext );
+        modifyDnRequest.getResultResponse().addAll( moveContext.getResponseControls() );
     }
 
 
@@ -888,13 +888,13 @@ public class DefaultCoreSession implemen
      */
     public void moveAndRename( InternalModifyDnRequest modifyDnRequest, LogChange log ) throws LdapException
     {
-        MoveAndRenameOperationContext opContext = new MoveAndRenameOperationContext( this, modifyDnRequest );
+        MoveAndRenameOperationContext moveAndRenameContext = new MoveAndRenameOperationContext( this, modifyDnRequest );
 
-        opContext.setLogChange( log );
+        moveAndRenameContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.moveAndRename( opContext );
-        modifyDnRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.moveAndRename( moveAndRenameContext );
+        modifyDnRequest.getResultResponse().addAll( moveAndRenameContext.getResponseControls() );
     }
 
 
@@ -912,22 +912,22 @@ public class DefaultCoreSession implemen
      */
     public void rename( InternalModifyDnRequest modifyDnRequest, LogChange log ) throws LdapException
     {
-        RenameOperationContext opContext = new RenameOperationContext( this, modifyDnRequest );
+        RenameOperationContext renameContext = new RenameOperationContext( this, modifyDnRequest );
 
-        opContext.setLogChange( log );
+        renameContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.rename( opContext );
-        modifyDnRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.rename( renameContext );
+        modifyDnRequest.getResultResponse().addAll( renameContext.getResponseControls() );
     }
 
 
     public EntryFilteringCursor search( InternalSearchRequest searchRequest ) throws LdapException
     {
-        SearchOperationContext opContext = new SearchOperationContext( this, searchRequest );
+        SearchOperationContext searchContext = new SearchOperationContext( this, searchRequest );
         OperationManager operationManager = directoryService.getOperationManager();
-        EntryFilteringCursor cursor = operationManager.search( opContext );
-        searchRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        EntryFilteringCursor cursor = operationManager.search( searchContext );
+        searchRequest.getResultResponse().addAll( searchContext.getResponseControls() );
         
         return cursor;
     }
@@ -943,6 +943,5 @@ public class DefaultCoreSession implemen
     public void unbind( InternalUnbindRequest unbindRequest )
     {
         // TODO Auto-generated method stub
-        
     }
 }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultOperationManager.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultOperationManager.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultOperationManager.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultOperationManager.java Tue Jun 15 21:15:04 2010
@@ -225,7 +225,7 @@ public class DefaultOperationManager imp
 
         try
         {
-            // Normalize the opContext DN
+            // Normalize the addContext DN
             DN dn = addContext.getDn();
             dn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
@@ -278,16 +278,16 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public void bind( BindOperationContext opContext ) throws LdapException
+    public void bind( BindOperationContext bindContext ) throws LdapException
     {
-        LOG.debug( ">> BindOperation : {}", opContext );
+        LOG.debug( ">> BindOperation : {}", bindContext );
 
         ensureStarted();
-        push( opContext );
+        push( bindContext );
 
         try
         {
-            directoryService.getInterceptorChain().bind( opContext );
+            directoryService.getInterceptorChain().bind( bindContext );
         }
         finally
         {
@@ -310,7 +310,7 @@ public class DefaultOperationManager imp
 
         try
         {
-            // Normalize the opContext DN
+            // Normalize the compareContext DN
             DN dn = compareContext.getDn();
             dn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
@@ -380,18 +380,18 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public void delete( DeleteOperationContext opContext ) throws LdapException
+    public void delete( DeleteOperationContext deleteContext ) throws LdapException
     {
-        LOG.debug( ">> DeleteOperation : {}", opContext );
-        LOG_CHANGES.debug( ">> DeleteOperation : {}", opContext );
+        LOG.debug( ">> DeleteOperation : {}", deleteContext );
+        LOG_CHANGES.debug( ">> DeleteOperation : {}", deleteContext );
 
         ensureStarted();
-        push( opContext );
+        push( deleteContext );
 
         try
         {
-            // Normalize the opContext DN
-            DN dn = opContext.getDn();
+            // Normalize the deleteContext DN
+            DN dn = deleteContext.getDn();
             dn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
             // We have to deal with the referral first
@@ -408,7 +408,7 @@ public class DefaultOperationManager imp
                 {
                     // This is a referral. We can delete it if the ManageDsaIt flag is true
                     // Otherwise, we just throw a LdapReferralException
-                    if ( !opContext.isReferralIgnored() )
+                    if ( !deleteContext.isReferralIgnored() )
                     {
                         // Throw a Referral Exception
                         // Unlock the referral manager
@@ -424,7 +424,7 @@ public class DefaultOperationManager imp
 
                     // Depending on the Context.REFERRAL property value, we will throw
                     // a different exception.
-                    if ( opContext.isReferralIgnored() )
+                    if ( deleteContext.isReferralIgnored() )
                     {
                         directoryService.getReferralManager().unlock();
 
@@ -447,7 +447,7 @@ public class DefaultOperationManager imp
 
             // Call the Add method
             InterceptorChain interceptorChain = directoryService.getInterceptorChain();
-            interceptorChain.delete( opContext );
+            interceptorChain.delete( deleteContext );
         }
         finally
         {
@@ -462,17 +462,17 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public Entry getRootDSE( GetRootDSEOperationContext opContext ) throws LdapException
+    public Entry getRootDSE( GetRootDSEOperationContext getRootDseContext ) throws LdapException
     {
-        LOG.debug( ">> GetRootDSEOperation : {}", opContext );
+        LOG.debug( ">> GetRootDSEOperation : {}", getRootDseContext );
 
         ensureStarted();
-        push( opContext );
+        push( getRootDseContext );
 
         try
         {
             InterceptorChain chain = directoryService.getInterceptorChain();
-            return chain.getRootDSE( opContext );
+            return chain.getRootDSE( getRootDseContext );
         }
         finally
         {
@@ -486,16 +486,16 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public boolean hasEntry( EntryOperationContext opContext ) throws LdapException
+    public boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException
     {
-        LOG.debug( ">> hasEntryOperation : {}", opContext );
+        LOG.debug( ">> hasEntryOperation : {}", hasEntryContext );
 
         ensureStarted();
-        push( opContext );
+        push( hasEntryContext );
 
         try
         {
-            return directoryService.getInterceptorChain().hasEntry( opContext );
+            return directoryService.getInterceptorChain().hasEntry( hasEntryContext );
         }
         finally
         {
@@ -509,16 +509,16 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException
     {
-        LOG.debug( ">> ListOperation : {}", opContext );
+        LOG.debug( ">> ListOperation : {}", listContext );
 
         ensureStarted();
-        push( opContext );
+        push( listContext );
 
         try
         {
-            return directoryService.getInterceptorChain().list( opContext );
+            return directoryService.getInterceptorChain().list( listContext );
         }
         finally
         {
@@ -532,17 +532,17 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public Entry lookup( LookupOperationContext opContext ) throws LdapException
+    public Entry lookup( LookupOperationContext lookupContext ) throws LdapException
     {
-        LOG.debug( ">> LookupOperation : {}", opContext );
+        LOG.debug( ">> LookupOperation : {}", lookupContext );
 
         ensureStarted();
-        push( opContext );
+        push( lookupContext );
 
         try
         {
             InterceptorChain chain = directoryService.getInterceptorChain();
-            return chain.lookup( opContext );
+            return chain.lookup( lookupContext );
         }
         finally
         {
@@ -556,18 +556,18 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public void modify( ModifyOperationContext opContext ) throws LdapException
+    public void modify( ModifyOperationContext modifyContext ) throws LdapException
     {
-        LOG.debug( ">> ModifyOperation : {}", opContext );
-        LOG_CHANGES.debug( ">> ModifyOperation : {}", opContext );
+        LOG.debug( ">> ModifyOperation : {}", modifyContext );
+        LOG_CHANGES.debug( ">> ModifyOperation : {}", modifyContext );
 
         ensureStarted();
-        push( opContext );
+        push( modifyContext );
 
         try
         {
-            // Normalize the opContext DN
-            DN dn = opContext.getDn();
+            // Normalize the modifyContext DN
+            DN dn = modifyContext.getDn();
             dn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
             ReferralManager referralManager = directoryService.getReferralManager();
@@ -584,7 +584,7 @@ public class DefaultOperationManager imp
                 {
                     // This is a referral. We can delete it if the ManageDsaIt flag is true
                     // Otherwise, we just throw a LdapReferralException
-                    if ( !opContext.isReferralIgnored() )
+                    if ( !modifyContext.isReferralIgnored() )
                     {
                         // Throw a Referral Exception
                         // Unlock the referral manager
@@ -603,7 +603,7 @@ public class DefaultOperationManager imp
 
                     // Depending on the Context.REFERRAL property value, we will throw
                     // a different exception.
-                    if ( opContext.isReferralIgnored() )
+                    if ( modifyContext.isReferralIgnored() )
                     {
                         referralManager.unlock();
 
@@ -632,7 +632,7 @@ public class DefaultOperationManager imp
 
             // Call the Add method
             InterceptorChain interceptorChain = directoryService.getInterceptorChain();
-            interceptorChain.modify( opContext );
+            interceptorChain.modify( modifyContext );
         }
         finally
         {
@@ -647,22 +647,22 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public void move( MoveOperationContext opContext ) throws LdapException
+    public void move( MoveOperationContext moveContext ) throws LdapException
     {
-        LOG.debug( ">> MoveOperation : {}", opContext );
-        LOG_CHANGES.debug( ">> MoveOperation : {}", opContext );
+        LOG.debug( ">> MoveOperation : {}", moveContext );
+        LOG_CHANGES.debug( ">> MoveOperation : {}", moveContext );
 
         ensureStarted();
-        push( opContext );
+        push( moveContext );
 
         try
         {
-            // Normalize the opContext DN
-            DN dn = opContext.getDn();
+            // Normalize the moveContext DN
+            DN dn = moveContext.getDn();
             dn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
-            // Normalize the opContext superior DN
-            DN newSuperiorDn = opContext.getNewSuperior();
+            // Normalize the moveContext superior DN
+            DN newSuperiorDn = moveContext.getNewSuperior();
             newSuperiorDn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
             // We have to deal with the referral first
@@ -680,7 +680,7 @@ public class DefaultOperationManager imp
                 {
                     // This is a referral. We can delete it if the ManageDsaIt flag is true
                     // Otherwise, we just throw a LdapReferralException
-                    if ( !opContext.isReferralIgnored() )
+                    if ( !moveContext.isReferralIgnored() )
                     {
                         // Throw a Referral Exception
                         // Unlock the referral manager
@@ -696,7 +696,7 @@ public class DefaultOperationManager imp
 
                     // Depending on the Context.REFERRAL property value, we will throw
                     // a different exception.
-                    if ( opContext.isReferralIgnored() )
+                    if ( moveContext.isReferralIgnored() )
                     {
                         directoryService.getReferralManager().unlock();
 
@@ -734,7 +734,7 @@ public class DefaultOperationManager imp
 
             // Call the Add method
             InterceptorChain interceptorChain = directoryService.getInterceptorChain();
-            interceptorChain.move( opContext );
+            interceptorChain.move( moveContext );
         }
         finally
         {
@@ -759,7 +759,7 @@ public class DefaultOperationManager imp
 
         try
         {
-            // Normalize the opContext DN
+            // Normalize the moveAndRenameContext DN
             DN dn = moveAndRenameContext.getDn();
             dn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
@@ -813,7 +813,7 @@ public class DefaultOperationManager imp
             }
 
             // Now, check the destination
-            // Normalize the opContext DN
+            // Normalize the moveAndRenameContext DN
             DN newSuperiorDn = moveAndRenameContext.getNewSuperiorDn();
             newSuperiorDn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
@@ -853,18 +853,18 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc} 
      */
-    public void rename( RenameOperationContext opContext ) throws LdapException
+    public void rename( RenameOperationContext renameContext ) throws LdapException
     {
-        LOG.debug( ">> RenameOperation : {}", opContext );
-        LOG_CHANGES.debug( ">> RenameOperation : {}", opContext );
+        LOG.debug( ">> RenameOperation : {}", renameContext );
+        LOG_CHANGES.debug( ">> RenameOperation : {}", renameContext );
 
         ensureStarted();
-        push( opContext );
+        push( renameContext );
 
         try
         {
-            // Normalize the opContext DN
-            DN dn = opContext.getDn();
+            // Normalize the renameContext DN
+            DN dn = renameContext.getDn();
             dn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
             // Inject the newDn into the operation context
@@ -873,8 +873,8 @@ public class DefaultOperationManager imp
             {
                 DN newDn = ( DN ) dn.clone();
                 newDn.remove( dn.size() - 1 );
-                newDn.add( opContext.getNewRdn() );
-                opContext.setNewDn( newDn );
+                newDn.add( renameContext.getNewRdn() );
+                renameContext.setNewDn( newDn );
             }
 
             // We have to deal with the referral first
@@ -892,7 +892,7 @@ public class DefaultOperationManager imp
                 {
                     // This is a referral. We can delete it if the ManageDsaIt flag is true
                     // Otherwise, we just throw a LdapReferralException
-                    if ( !opContext.isReferralIgnored() )
+                    if ( !renameContext.isReferralIgnored() )
                     {
                         // Throw a Referral Exception
                         // Unlock the referral manager
@@ -908,7 +908,7 @@ public class DefaultOperationManager imp
 
                     // Depending on the Context.REFERRAL property value, we will throw
                     // a different exception.
-                    if ( opContext.isReferralIgnored() )
+                    if ( renameContext.isReferralIgnored() )
                     {
                         directoryService.getReferralManager().unlock();
 
@@ -931,7 +931,7 @@ public class DefaultOperationManager imp
 
             // Call the Add method
             InterceptorChain interceptorChain = directoryService.getInterceptorChain();
-            interceptorChain.rename( opContext );
+            interceptorChain.rename( renameContext );
         }
         finally
         {
@@ -946,17 +946,17 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException
     {
-        LOG.debug( ">> SearchOperation : {}", opContext );
+        LOG.debug( ">> SearchOperation : {}", searchContext );
 
         ensureStarted();
-        push( opContext );
+        push( searchContext );
 
         try
         {
-            // Normalize the opContext DN
-            DN dn = opContext.getDn();
+            // Normalize the searchContext DN
+            DN dn = searchContext.getDn();
             dn.normalize( directoryService.getSchemaManager().getNormalizerMapping() );
 
             // We have to deal with the referral first
@@ -974,14 +974,14 @@ public class DefaultOperationManager imp
                 {
                     // This is a referral. We can return it if the ManageDsaIt flag is true
                     // Otherwise, we just throw a LdapReferralException
-                    if ( !opContext.isReferralIgnored() )
+                    if ( !searchContext.isReferralIgnored() )
                     {
                         // Throw a Referral Exception
                         // Unlock the referral manager
                         directoryService.getReferralManager().unlock();
 
                         LdapReferralException exception = buildReferralExceptionForSearch( parentEntry, childDn,
-                            opContext.getScope() );
+                            searchContext.getScope() );
                         throw exception;
                     }
                 }
@@ -991,7 +991,7 @@ public class DefaultOperationManager imp
 
                     // Depending on the Context.REFERRAL property value, we will throw
                     // a different exception.
-                    if ( opContext.isReferralIgnored() )
+                    if ( searchContext.isReferralIgnored() )
                     {
                         directoryService.getReferralManager().unlock();
 
@@ -1004,7 +1004,7 @@ public class DefaultOperationManager imp
                         directoryService.getReferralManager().unlock();
 
                         LdapReferralException exception = buildReferralExceptionForSearch( parentEntry, childDn,
-                            opContext.getScope() );
+                            searchContext.getScope() );
                         throw exception;
                     }
                 }
@@ -1015,7 +1015,7 @@ public class DefaultOperationManager imp
 
             // Call the Add method
             InterceptorChain interceptorChain = directoryService.getInterceptorChain();
-            return interceptorChain.search( opContext );
+            return interceptorChain.search( searchContext );
         }
         finally
         {
@@ -1029,16 +1029,16 @@ public class DefaultOperationManager imp
     /**
      * {@inheritDoc}
      */
-    public void unbind( UnbindOperationContext opContext ) throws LdapException
+    public void unbind( UnbindOperationContext unbindContext ) throws LdapException
     {
-        LOG.debug( ">> UnbindOperation : {}", opContext );
+        LOG.debug( ">> UnbindOperation : {}", unbindContext );
 
         ensureStarted();
-        push( opContext );
+        push( unbindContext );
 
         try
         {
-            directoryService.getInterceptorChain().unbind( opContext );
+            directoryService.getInterceptorChain().unbind( unbindContext );
         }
         finally
         {

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AnonymousAuthenticator.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AnonymousAuthenticator.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AnonymousAuthenticator.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AnonymousAuthenticator.java Tue Jun 15 21:15:04 2010
@@ -48,7 +48,7 @@ public class AnonymousAuthenticator exte
      * If the context is not configured to allow anonymous connections,
      * this method throws a {@link javax.naming.NoPermissionException}.
      */
-    public LdapPrincipal authenticate( BindOperationContext opContext ) throws LdapNoPermissionException
+    public LdapPrincipal authenticate( BindOperationContext bindContext ) throws LdapNoPermissionException
     {
         // We only allow Anonymous binds if the service allows them
         if ( getDirectoryService().isAllowAnonymousAccess() )

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AuthenticationInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AuthenticationInterceptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AuthenticationInterceptor.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AuthenticationInterceptor.java Tue Jun 15 21:15:04 2010
@@ -208,64 +208,64 @@ public class AuthenticationInterceptor e
     }
 
 
-    public void delete( NextInterceptor next, DeleteOperationContext opContext ) throws LdapException
+    public void delete( NextInterceptor next, DeleteOperationContext deleteContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", deleteContext );
         }
 
-        checkAuthenticated( opContext );
-        next.delete( opContext );
-        invalidateAuthenticatorCaches( opContext.getDn() );
+        checkAuthenticated( deleteContext );
+        next.delete( deleteContext );
+        invalidateAuthenticatorCaches( deleteContext.getDn() );
     }
 
 
-    public Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext opContext ) throws LdapException
+    public Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext getRootDseContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", getRootDseContext );
         }
 
-        checkAuthenticated( opContext );
-        return next.getRootDSE( opContext );
+        checkAuthenticated( getRootDseContext );
+        return next.getRootDSE( getRootDseContext );
     }
 
 
-    public boolean hasEntry( NextInterceptor next, EntryOperationContext opContext ) throws LdapException
+    public boolean hasEntry( NextInterceptor next, EntryOperationContext hasEntryContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", hasEntryContext );
         }
 
-        checkAuthenticated( opContext );
-        return next.hasEntry( opContext );
+        checkAuthenticated( hasEntryContext );
+        return next.hasEntry( hasEntryContext );
     }
 
 
-    public EntryFilteringCursor list( NextInterceptor next, ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( NextInterceptor next, ListOperationContext listContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", listContext );
         }
 
-        checkAuthenticated( opContext );
-        return next.list( opContext );
+        checkAuthenticated( listContext );
+        return next.list( listContext );
     }
 
 
-    public Entry lookup( NextInterceptor next, LookupOperationContext opContext ) throws LdapException
+    public Entry lookup( NextInterceptor next, LookupOperationContext lookupContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", lookupContext );
         }
 
-        checkAuthenticated( opContext );
-        return next.lookup( opContext );
+        checkAuthenticated( lookupContext );
+        return next.lookup( lookupContext );
     }
 
     
@@ -284,29 +284,29 @@ public class AuthenticationInterceptor e
     }
 
 
-    public void modify( NextInterceptor next, ModifyOperationContext opContext ) throws LdapException
+    public void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", modifyContext );
         }
 
-        checkAuthenticated( opContext );
-        next.modify( opContext );
-        invalidateAuthenticatorCaches( opContext.getDn() );
+        checkAuthenticated( modifyContext );
+        next.modify( modifyContext );
+        invalidateAuthenticatorCaches( modifyContext.getDn() );
     }
 
 
-    public void rename( NextInterceptor next, RenameOperationContext opContext ) throws LdapException
+    public void rename( NextInterceptor next, RenameOperationContext renameContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", renameContext );
         }
 
-        checkAuthenticated( opContext );
-        next.rename( opContext );
-        invalidateAuthenticatorCaches( opContext.getDn() );
+        checkAuthenticated( renameContext );
+        next.rename( renameContext );
+        invalidateAuthenticatorCaches( renameContext.getDn() );
     }
 
     
@@ -358,22 +358,21 @@ public class AuthenticationInterceptor e
     }
 
 
-    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", searchContext );
         }
 
-        checkAuthenticated( opContext );
-        return next.search( opContext );
+        checkAuthenticated( searchContext );
+        return next.search( searchContext );
     }
 
 
     /**
      * Check if the current operation has a valid PrincipalDN or not.
      *
-     * @param opContext the OperationContext for this operation
      * @param operation the operation type
      * @throws Exception
      */
@@ -389,28 +388,28 @@ public class AuthenticationInterceptor e
     }
 
 
-    public void bind( NextInterceptor next, BindOperationContext opContext ) throws LdapException
+    public void bind( NextInterceptor next, BindOperationContext bindContext ) throws LdapException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Operation Context: {}", opContext );
+            LOG.debug( "Operation Context: {}", bindContext );
         }
 
-        if ( ( opContext.getSession() != null ) && ( opContext.getSession().getEffectivePrincipal() != null ) )
+        if ( ( bindContext.getSession() != null ) && ( bindContext.getSession().getEffectivePrincipal() != null ) )
         {
             // null out the credentials
-            opContext.setCredentials( null );
+            bindContext.setCredentials( null );
         }
         
         // pick the first matching authenticator type
-        AuthenticationLevel level = opContext.getAuthenticationLevel();
+        AuthenticationLevel level = bindContext.getAuthenticationLevel();
         
         if ( level == AuthenticationLevel.UNAUTHENT )
         {
             // This is a case where the Bind request contains a DN, but no password.
             // We don't check the DN, we just return a UnwillingToPerform error
             // Cf RFC 4513, chap. 5.1.2
-            throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM, "Cannot Bind for DN " + opContext.getDn().getName() );
+            throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM, "Cannot Bind for DN " + bindContext.getDn().getName() );
         }
 
         Collection<Authenticator> authenticators = getAuthenticators( level );
@@ -420,18 +419,18 @@ public class AuthenticationInterceptor e
             LOG.debug( "No authenticators found, delegating bind to the nexus." );
 
             // as a last resort try binding via the nexus
-            next.bind( opContext );
+            next.bind( bindContext );
 
             LOG.debug( "Nexus succeeded on bind operation." );
 
             // bind succeeded if we got this far
             // TODO - authentication level not being set
-            LdapPrincipal principal = new LdapPrincipal( opContext.getDn(), AuthenticationLevel.SIMPLE );
+            LdapPrincipal principal = new LdapPrincipal( bindContext.getDn(), AuthenticationLevel.SIMPLE );
             CoreSession session = new DefaultCoreSession( principal, directoryService );
-            opContext.setSession( session );
+            bindContext.setSession( session );
 
             // remove creds so there is no security risk
-            opContext.setCredentials( null );
+            bindContext.setCredentials( null );
             return;
         }
 
@@ -442,17 +441,17 @@ public class AuthenticationInterceptor e
             try
             {
                 // perform the authentication
-                LdapPrincipal principal = authenticator.authenticate( opContext );
+                LdapPrincipal principal = authenticator.authenticate( bindContext );
                 
                 LdapPrincipal clonedPrincipal = (LdapPrincipal)(principal.clone());
 
                 // remove creds so there is no security risk
-                opContext.setCredentials( null );
+                bindContext.setCredentials( null );
                 clonedPrincipal.setUserPassword( StringTools.EMPTY_BYTES );
 
                 // authentication was successful
                 CoreSession session = new DefaultCoreSession( clonedPrincipal, directoryService );
-                opContext.setSession( session );
+                bindContext.setSession( session );
 
                 return;
             }
@@ -461,7 +460,7 @@ public class AuthenticationInterceptor e
                 // authentication failed, try the next authenticator
                 if ( LOG.isInfoEnabled() )
                 {
-                    LOG.info( "Authenticator {} failed to authenticate: {}", authenticator, opContext );
+                    LOG.info( "Authenticator {} failed to authenticate: {}", authenticator, bindContext );
                 }
             }
             catch ( Exception e )
@@ -469,7 +468,7 @@ public class AuthenticationInterceptor e
                 // Log other exceptions than LdapAuthenticationException
                 if ( LOG.isWarnEnabled() )
                 {
-                    LOG.info( "Unexpected failure for Authenticator {} : {}", authenticator, opContext );
+                    LOG.info( "Unexpected failure for Authenticator {} : {}", authenticator, bindContext );
                 }
             }
         }
@@ -479,7 +478,7 @@ public class AuthenticationInterceptor e
             LOG.info( "Cannot bind to the server " );
         }
 
-        DN dn = opContext.getDn();
+        DN dn = bindContext.getDn();
         String upDn = ( dn == null ? "" : dn.getName() );
         throw new LdapAuthenticationException( I18n.err( I18n.ERR_229, upDn ) );
     }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/Authenticator.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/Authenticator.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/Authenticator.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/Authenticator.java Tue Jun 15 21:15:04 2010
@@ -83,5 +83,5 @@ public interface Authenticator
     /**
      * Performs authentication and returns the principal if succeeded.
      */
-    public LdapPrincipal authenticate( BindOperationContext opContext ) throws Exception;
+    public LdapPrincipal authenticate( BindOperationContext bindContext ) throws Exception;
 }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/SimpleAuthenticator.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/SimpleAuthenticator.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/StrongAuthenticator.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/StrongAuthenticator.java Tue Jun 15 21:15:04 2010
@@ -49,9 +49,9 @@ public class StrongAuthenticator extends
      * User has already been authenticated during SASL negotiation. Set the authentication level
      * to strong and return an {@link LdapPrincipal}.
      */
-    public LdapPrincipal authenticate( BindOperationContext opContext ) throws LdapAuthenticationException
+    public LdapPrincipal authenticate( BindOperationContext bindContext ) throws LdapAuthenticationException
     {
         // Possibly check if user account is disabled, other account checks.
-        return new LdapPrincipal( opContext.getDn(), AuthenticationLevel.STRONG );
+        return new LdapPrincipal( bindContext.getDn(), AuthenticationLevel.STRONG );
     }
 }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/AciAuthorizationInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/AciAuthorizationInterceptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/AciAuthorizationInterceptor.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/AciAuthorizationInterceptor.java Tue Jun 15 21:15:04 2010
@@ -540,34 +540,34 @@ public class AciAuthorizationInterceptor
 
     // False positive, we want to keep the comment
     @SuppressWarnings("PMD.CollapsibleIfStatements")
-    public void modify( NextInterceptor next, ModifyOperationContext opContext ) throws LdapException
+    public void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException
     {
-        DN dn = opContext.getDn();
+        DN dn = modifyContext.getDn();
 
         // Access the principal requesting the operation, and bypass checks if it is the admin
-        Entry entry = opContext.getEntry();
+        Entry entry = modifyContext.getEntry();
 
-        LdapPrincipal principal = opContext.getSession().getEffectivePrincipal();
+        LdapPrincipal principal = modifyContext.getSession().getEffectivePrincipal();
         DN principalDn = principal.getDN();
 
         // bypass authz code if we are disabled
-        if ( !opContext.getSession().getDirectoryService().isAccessControlEnabled() )
+        if ( !modifyContext.getSession().getDirectoryService().isAccessControlEnabled() )
         {
-            next.modify( opContext );
+            next.modify( modifyContext );
             return;
         }
 
-        List<Modification> mods = opContext.getModItems();
+        List<Modification> mods = modifyContext.getModItems();
 
         // bypass authz code but manage caches if operation is performed by the admin
         if ( isPrincipalAnAdministrator( principalDn ) )
         {
-            next.modify( opContext );
+            next.modify( modifyContext );
 
             /**
              * @TODO: A virtual entry can be created here for not hitting the backend again.
              */
-            Entry modifiedEntry = opContext.lookup( dn, ByPassConstants.LOOKUP_BYPASS );
+            Entry modifiedEntry = modifyContext.lookup( dn, ByPassConstants.LOOKUP_BYPASS );
             tupleCache.subentryModified( dn, mods, modifiedEntry );
             groupCache.groupModified( dn, mods, entry, schemaManager );
             return;
@@ -575,11 +575,11 @@ public class AciAuthorizationInterceptor
 
         Set<DN> userGroups = groupCache.getGroups( principalDn.getName() );
         Collection<ACITuple> tuples = new HashSet<ACITuple>();
-        addPerscriptiveAciTuples( opContext, tuples, dn, ( ( ClonedServerEntry ) entry ).getOriginalEntry() );
+        addPerscriptiveAciTuples( modifyContext, tuples, dn, ( ( ClonedServerEntry ) entry ).getOriginalEntry() );
         addEntryAciTuples( tuples, entry );
-        addSubentryAciTuples( opContext, tuples, dn, entry );
+        addSubentryAciTuples( modifyContext, tuples, dn, entry );
 
-        engine.checkPermission( schemaManager, opContext, userGroups, principalDn, principal.getAuthenticationLevel(),
+        engine.checkPermission( schemaManager, modifyContext, userGroups, principalDn, principal.getAuthenticationLevel(),
             dn, null, null, Collections.singleton( MicroOperation.MODIFY ), tuples, entry, null );
 
         Collection<MicroOperation> perms = null;
@@ -598,7 +598,7 @@ public class AciAuthorizationInterceptor
                     if ( entry.get( attr.getId() ) == null )
                     {
                         // ... we also need to check if adding the attribute is permitted
-                        engine.checkPermission( schemaManager, opContext, userGroups, principalDn, principal
+                        engine.checkPermission( schemaManager, modifyContext, userGroups, principalDn, principal
                             .getAuthenticationLevel(), dn, attr.getId(), null, perms, tuples, entry, null );
                     }
 
@@ -614,7 +614,7 @@ public class AciAuthorizationInterceptor
                         if ( entryAttr.size() == 1 )
                         {
                             // ... we also need to check if removing the attribute at all is permitted
-                            engine.checkPermission( schemaManager, opContext, userGroups, principalDn, principal
+                            engine.checkPermission( schemaManager, modifyContext, userGroups, principalDn, principal
                                 .getAuthenticationLevel(), dn, attr.getId(), null, perms, tuples, entry, null );
                         }
                     }
@@ -643,31 +643,31 @@ public class AciAuthorizationInterceptor
 
             for ( Value<?> value : attr )
             {
-                engine.checkPermission( schemaManager, opContext, userGroups, principalDn, principal
+                engine.checkPermission( schemaManager, modifyContext, userGroups, principalDn, principal
                     .getAuthenticationLevel(), dn, attr.getId(), value, perms, tuples, entry, entryView );
             }
         }
 
-        next.modify( opContext );
+        next.modify( modifyContext );
         /**
          * @TODO: A virtual entry can be created here for not hitting the backend again.
          */
-        Entry modifiedEntry = opContext.lookup( dn, ByPassConstants.LOOKUP_BYPASS );
+        Entry modifiedEntry = modifyContext.lookup( dn, ByPassConstants.LOOKUP_BYPASS );
         tupleCache.subentryModified( dn, mods, modifiedEntry );
         groupCache.groupModified( dn, mods, entry, schemaManager );
     }
 
 
-    public boolean hasEntry( NextInterceptor next, EntryOperationContext entryContext ) throws LdapException
+    public boolean hasEntry( NextInterceptor next, EntryOperationContext hasEntryContext ) throws LdapException
     {
-        DN dn = entryContext.getDn();
+        DN dn = hasEntryContext.getDn();
 
-        if ( !entryContext.getSession().getDirectoryService().isAccessControlEnabled() )
+        if ( !hasEntryContext.getSession().getDirectoryService().isAccessControlEnabled() )
         {
-            return ( dn.isRootDSE() || next.hasEntry( entryContext ) );
+            return ( dn.isRootDSE() || next.hasEntry( hasEntryContext ) );
         }
 
-        boolean answer = next.hasEntry( entryContext );
+        boolean answer = next.hasEntry( hasEntryContext );
 
         // no checks on the RootDSE
         if ( dn.isRootDSE() )
@@ -678,7 +678,7 @@ public class AciAuthorizationInterceptor
         }
 
         // TODO - eventually replace this with a check on session.isAnAdministrator()
-        LdapPrincipal principal = entryContext.getSession().getEffectivePrincipal();
+        LdapPrincipal principal = hasEntryContext.getSession().getEffectivePrincipal();
         DN principalDn = principal.getDN();
         
         if ( isPrincipalAnAdministrator( principalDn ) )
@@ -686,19 +686,19 @@ public class AciAuthorizationInterceptor
             return answer;
         }
 
-        Entry entry = entryContext.lookup( dn, ByPassConstants.HAS_ENTRY_BYPASS );
+        Entry entry = hasEntryContext.lookup( dn, ByPassConstants.HAS_ENTRY_BYPASS );
         Set<DN> userGroups = groupCache.getGroups( principalDn.getNormName() );
         Collection<ACITuple> tuples = new HashSet<ACITuple>();
-        addPerscriptiveAciTuples( entryContext, tuples, dn, ( ( ClonedServerEntry ) entry ).getOriginalEntry() );
+        addPerscriptiveAciTuples( hasEntryContext, tuples, dn, ( ( ClonedServerEntry ) entry ).getOriginalEntry() );
         addEntryAciTuples( tuples, ( ( ClonedServerEntry ) entry ).getOriginalEntry() );
-        addSubentryAciTuples( entryContext, tuples, dn, ( ( ClonedServerEntry ) entry ).getOriginalEntry() );
+        addSubentryAciTuples( hasEntryContext, tuples, dn, ( ( ClonedServerEntry ) entry ).getOriginalEntry() );
 
         // check that we have browse access to the entry
-        engine.checkPermission( schemaManager, entryContext, userGroups, principalDn, principal
+        engine.checkPermission( schemaManager, hasEntryContext, userGroups, principalDn, principal
             .getAuthenticationLevel(), dn, null, null, BROWSE_PERMS, tuples, ( ( ClonedServerEntry ) entry )
             .getOriginalEntry(), null );
 
-        return next.hasEntry( entryContext );
+        return next.hasEntry( hasEntryContext );
     }
 
 
@@ -980,13 +980,13 @@ public class AciAuthorizationInterceptor
     }
 
 
-    public EntryFilteringCursor list( NextInterceptor next, ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( NextInterceptor next, ListOperationContext listContext ) throws LdapException
     {
-        LdapPrincipal user = opContext.getSession().getEffectivePrincipal();
-        EntryFilteringCursor cursor = next.list( opContext );
+        LdapPrincipal user = listContext.getSession().getEffectivePrincipal();
+        EntryFilteringCursor cursor = next.list( listContext );
 
         if ( isPrincipalAnAdministrator( user.getDNRef() )
-            || !opContext.getSession().getDirectoryService().isAccessControlEnabled() )
+            || !listContext.getSession().getDirectoryService().isAccessControlEnabled() )
         {
             return cursor;
         }
@@ -997,19 +997,19 @@ public class AciAuthorizationInterceptor
     }
 
 
-    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException
     {
-        LdapPrincipal user = opContext.getSession().getEffectivePrincipal();
+        LdapPrincipal user = searchContext.getSession().getEffectivePrincipal();
         DN principalDn = user.getDN();
-        EntryFilteringCursor cursor = next.search( opContext );
+        EntryFilteringCursor cursor = next.search( searchContext );
 
-        boolean isSubschemaSubentryLookup = subschemaSubentryDn.equals( opContext.getDn().getNormName() );
-        SearchControls searchCtls = opContext.getSearchControls();
-        boolean isRootDSELookup = opContext.getDn().size() == 0
+        boolean isSubschemaSubentryLookup = subschemaSubentryDn.equals( searchContext.getDn().getNormName() );
+        SearchControls searchCtls = searchContext.getSearchControls();
+        boolean isRootDSELookup = searchContext.getDn().size() == 0
             && searchCtls.getSearchScope() == SearchControls.OBJECT_SCOPE;
 
         if ( isPrincipalAnAdministrator( principalDn )
-            || !opContext.getSession().getDirectoryService().isAccessControlEnabled() || isRootDSELookup
+            || !searchContext.getSession().getDirectoryService().isAccessControlEnabled() || isRootDSELookup
             || isSubschemaSubentryLookup )
         {
             return cursor;
@@ -1149,10 +1149,10 @@ public class AciAuthorizationInterceptor
      */
     class AuthorizationFilter implements EntryFilter
     {
-        public boolean accept( SearchingOperationContext operationContext, ClonedServerEntry entry ) throws Exception
+        public boolean accept( SearchingOperationContext searchContext, ClonedServerEntry entry ) throws Exception
         {
             DN normName = entry.getDn().normalize( schemaManager.getNormalizerMapping() );
-            return filter( operationContext, normName, entry );
+            return filter( searchContext, normName, entry );
         }
     }
 }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/DefaultAuthorizationInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/DefaultAuthorizationInterceptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/DefaultAuthorizationInterceptor.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/DefaultAuthorizationInterceptor.java Tue Jun 15 21:15:04 2010
@@ -155,15 +155,15 @@ public class DefaultAuthorizationInterce
     //    Lookup, search and list operations need to be handled using a filter
     // and so we need access to the filter service.
 
-    public void delete( NextInterceptor nextInterceptor, DeleteOperationContext opContext ) throws LdapException
+    public void delete( NextInterceptor nextInterceptor, DeleteOperationContext deleteContext ) throws LdapException
     {
-        if ( opContext.getSession().getDirectoryService().isAccessControlEnabled() )
+        if ( deleteContext.getSession().getDirectoryService().isAccessControlEnabled() )
         {
-            nextInterceptor.delete( opContext );
+            nextInterceptor.delete( deleteContext );
             return;
         }
 
-        DN dn = opContext.getDn();
+        DN dn = deleteContext.getDn();
 
         if ( dn.isEmpty() )
         {
@@ -205,7 +205,7 @@ public class DefaultAuthorizationInterce
             }
         }
 
-        nextInterceptor.delete( opContext );
+        nextInterceptor.delete( deleteContext );
     }
 
 
@@ -231,24 +231,24 @@ public class DefaultAuthorizationInterce
      * users to self access these resources.  As far as we're concerned no one but
      * the admin needs access.
      */
-    public void modify( NextInterceptor nextInterceptor, ModifyOperationContext opContext ) throws LdapException
+    public void modify( NextInterceptor nextInterceptor, ModifyOperationContext modifyContext ) throws LdapException
     {
-        if ( !opContext.getSession().getDirectoryService().isAccessControlEnabled() )
+        if ( !modifyContext.getSession().getDirectoryService().isAccessControlEnabled() )
         {
-            DN dn = opContext.getDn();
+            DN dn = modifyContext.getDn();
 
             protectModifyAlterations( dn );
-            nextInterceptor.modify( opContext );
+            nextInterceptor.modify( modifyContext );
 
             // update administrators if we change administrators group
             if ( dn.equals( ADMIN_GROUP_DN ) )
             {
-                loadAdministrators( opContext.getSession().getDirectoryService() );
+                loadAdministrators( modifyContext.getSession().getDirectoryService() );
             }
         }
         else
         {
-            nextInterceptor.modify( opContext );
+            nextInterceptor.modify( modifyContext );
         }
     }
 
@@ -308,14 +308,14 @@ public class DefaultAuthorizationInterce
     //  o The administrator entry cannot be moved or renamed by anyone
     // ------------------------------------------------------------------------
 
-    public void rename( NextInterceptor nextInterceptor, RenameOperationContext opContext ) throws LdapException
+    public void rename( NextInterceptor nextInterceptor, RenameOperationContext renameContext ) throws LdapException
     {
-        if ( !opContext.getSession().getDirectoryService().isAccessControlEnabled() )
+        if ( !renameContext.getSession().getDirectoryService().isAccessControlEnabled() )
         {
-            protectDnAlterations( opContext.getDn() );
+            protectDnAlterations( renameContext.getDn() );
         }
 
-        nextInterceptor.rename( opContext );
+        nextInterceptor.rename( renameContext );
     }
 
 
@@ -386,17 +386,17 @@ public class DefaultAuthorizationInterce
     }
 
 
-    public Entry lookup( NextInterceptor nextInterceptor, LookupOperationContext opContext ) throws LdapException
+    public Entry lookup( NextInterceptor nextInterceptor, LookupOperationContext lookupContext ) throws LdapException
     {
-        CoreSession session = opContext.getSession();
-        Entry entry = nextInterceptor.lookup( opContext );
+        CoreSession session = lookupContext.getSession();
+        Entry entry = nextInterceptor.lookup( lookupContext );
 
         if ( session.getDirectoryService().isAccessControlEnabled() || ( entry == null ) )
         {
             return entry;
         }
 
-        protectLookUp( session.getEffectivePrincipal().getDNRef(), opContext.getDn() );
+        protectLookUp( session.getEffectivePrincipal().getDNRef(), lookupContext.getDn() );
 
         return entry;
     }
@@ -451,12 +451,12 @@ public class DefaultAuthorizationInterce
     }
 
 
-    public EntryFilteringCursor search( NextInterceptor nextInterceptor, SearchOperationContext opContext )
+    public EntryFilteringCursor search( NextInterceptor nextInterceptor, SearchOperationContext searchContext )
         throws LdapException
     {
-        EntryFilteringCursor cursor = nextInterceptor.search( opContext );
+        EntryFilteringCursor cursor = nextInterceptor.search( searchContext );
 
-        if ( opContext.getSession().getDirectoryService().isAccessControlEnabled() )
+        if ( searchContext.getSession().getDirectoryService().isAccessControlEnabled() )
         {
             return cursor;
         }
@@ -472,12 +472,12 @@ public class DefaultAuthorizationInterce
     }
 
 
-    public EntryFilteringCursor list( NextInterceptor nextInterceptor, ListOperationContext opContext )
+    public EntryFilteringCursor list( NextInterceptor nextInterceptor, ListOperationContext listContext )
         throws LdapException
     {
-        EntryFilteringCursor cursor = nextInterceptor.list( opContext );
+        EntryFilteringCursor cursor = nextInterceptor.list( listContext );
 
-        if ( opContext.getSession().getDirectoryService().isAccessControlEnabled() )
+        if ( listContext.getSession().getDirectoryService().isAccessControlEnabled() )
         {
             return cursor;
         }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogInterceptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogInterceptor.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogInterceptor.java Tue Jun 15 21:15:04 2010
@@ -137,20 +137,20 @@ public class ChangeLogInterceptor extend
      * The delete operation has to be stored with a way to restore the deleted element.
      * There is no way to do that but reading the entry and dump it into the LOG.
      */
-    public void delete( NextInterceptor next, DeleteOperationContext opContext ) throws LdapException
+    public void delete( NextInterceptor next, DeleteOperationContext deleteContext ) throws LdapException
     {
         // @todo make sure we're not putting in operational attributes that cannot be user modified
         // must save the entry if change log is enabled
         Entry serverEntry = null;
 
-        if ( changeLog.isEnabled() && opContext.isFirstOperation() )
+        if ( changeLog.isEnabled() && deleteContext.isFirstOperation() )
         {
-            serverEntry = getAttributes( opContext );
+            serverEntry = getAttributes( deleteContext );
         }
 
-        next.delete( opContext );
+        next.delete( deleteContext );
 
-        if ( ! changeLog.isEnabled() || ! opContext.isFirstOperation() )
+        if ( ! changeLog.isEnabled() || ! deleteContext.isFirstOperation() )
         {
             return;
         }
@@ -163,7 +163,7 @@ public class ChangeLogInterceptor extend
 
         LdifEntry forward = new LdifEntry();
         forward.setChangeType( ChangeType.Delete );
-        forward.setDn( opContext.getDn() );
+        forward.setDn( deleteContext.getDn() );
         
         Entry reverseEntry = new DefaultEntry( serverEntry.getDn() );
 
@@ -177,8 +177,8 @@ public class ChangeLogInterceptor extend
             }
         }
 
-        LdifEntry reverse = LdifRevertor.reverseDel( opContext.getDn(), reverseEntry );
-        opContext.setChangeLogEvent( changeLog.log( getPrincipal(), forward, reverse ) );
+        LdifEntry reverse = LdifRevertor.reverseDel( deleteContext.getDn(), reverseEntry );
+        deleteContext.setChangeLogEvent( changeLog.log( getPrincipal(), forward, reverse ) );
     }
 
 
@@ -211,41 +211,41 @@ public class ChangeLogInterceptor extend
     /**
      * 
      */
-    public void modify( NextInterceptor next, ModifyOperationContext opContext ) throws LdapException
+    public void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException
     {
         Entry serverEntry = null;
-        Modification modification = ServerEntryUtils.getModificationItem( opContext.getModItems(), entryDeleted );
+        Modification modification = ServerEntryUtils.getModificationItem( modifyContext.getModItems(), entryDeleted );
         boolean isDelete = ( modification != null );
 
-        if ( ! isDelete && ( changeLog.isEnabled() && opContext.isFirstOperation() ) )
+        if ( ! isDelete && ( changeLog.isEnabled() && modifyContext.isFirstOperation() ) )
         {
             // @todo make sure we're not putting in operational attributes that cannot be user modified
-            serverEntry = getAttributes( opContext );
+            serverEntry = getAttributes( modifyContext );
         }
         
         // Duplicate modifications so that the reverse does not contain the operational attributes
         List<Modification> clonedMods = new ArrayList<Modification>(); 
 
-        for ( Modification mod : opContext.getModItems() )
+        for ( Modification mod : modifyContext.getModItems() )
         {
             clonedMods.add( mod.clone() );
         }
 
         // Call the next interceptor
-        next.modify( opContext );
+        next.modify( modifyContext );
 
         // @TODO: needs big consideration!!!
         // NOTE: perhaps we need to log this as a system operation that cannot and should not be reapplied?
         if ( 
             isDelete ||   
             ! changeLog.isEnabled() || 
-            ! opContext.isFirstOperation() ||
+            ! modifyContext.isFirstOperation() ||
             
          // if there are no modifications due to stripping out bogus non-
          // existing attributes then we will have no modification items and
          // should ignore not this without registering it with the changelog
          
-            opContext.getModItems().size() == 0 )  
+            modifyContext.getModItems().size() == 0 )  
         {
             if ( isDelete )
             {
@@ -257,7 +257,7 @@ public class ChangeLogInterceptor extend
 
         LdifEntry forward = new LdifEntry();
         forward.setChangeType( ChangeType.Modify );
-        forward.setDn( opContext.getDn() );
+        forward.setDn( modifyContext.getDn() );
         
         List<Modification> mods = new ArrayList<Modification>( clonedMods.size() );
         
@@ -277,11 +277,11 @@ public class ChangeLogInterceptor extend
         }
 
         LdifEntry reverse = LdifRevertor.reverseModify( 
-            opContext.getDn(), 
+            modifyContext.getDn(), 
             mods, 
             clientEntry );
         
-        opContext.setChangeLogEvent( changeLog.log( getPrincipal(), forward, reverse ) );
+        modifyContext.setChangeLogEvent( changeLog.log( getPrincipal(), forward, reverse ) );
     }
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/SimpleAuthenticator.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/SimpleAuthenticator.java Tue Jun 15 21:15:04 2010
@@ -187,13 +187,13 @@ public class SimpleAuthenticator extends
      * @return A byte array which can be empty if the password was not found
      * @throws Exception If we have a problem during the lookup operation
      */
-    private LdapPrincipal getStoredPassword( BindOperationContext opContext ) throws LdapAuthenticationException
+    private LdapPrincipal getStoredPassword( BindOperationContext bindContext ) throws LdapAuthenticationException
     {
         LdapPrincipal principal = null;
 
         synchronized ( credentialCache )
         {
-            principal = ( LdapPrincipal ) credentialCache.get( opContext.getDn().getNormName() );
+            principal = ( LdapPrincipal ) credentialCache.get( bindContext.getDn().getNormName() );
         }
 
         byte[] storedPassword;
@@ -202,7 +202,7 @@ public class SimpleAuthenticator extends
         {
             // Not found in the cache
             // Get the user password from the backend
-            storedPassword = lookupUserPassword( opContext );
+            storedPassword = lookupUserPassword( bindContext );
 
             // Deal with the special case where the user didn't enter a password
             // We will compare the empty array with the credentials. Sometime,
@@ -214,12 +214,12 @@ public class SimpleAuthenticator extends
             }
 
             // Create the new principal before storing it in the cache
-            principal = new LdapPrincipal( opContext.getDn(), AuthenticationLevel.SIMPLE, storedPassword );
+            principal = new LdapPrincipal( bindContext.getDn(), AuthenticationLevel.SIMPLE, storedPassword );
 
             // Now, update the local cache.
             synchronized ( credentialCache )
             {
-                credentialCache.put( opContext.getDn().getNormName(), principal );
+                credentialCache.put( bindContext.getDn().getNormName(), principal );
             }
         }
 
@@ -268,17 +268,17 @@ public class SimpleAuthenticator extends
      *  The stored password is always using the unsalted form, and is stored as a bytes array.
      *  </p>
      */
-    public LdapPrincipal authenticate( BindOperationContext opContext ) throws LdapAuthenticationException
+    public LdapPrincipal authenticate( BindOperationContext bindContext ) throws LdapAuthenticationException
     {
         if ( IS_DEBUG )
         {
-            LOG.debug( "Authenticating {}", opContext.getDn() );
+            LOG.debug( "Authenticating {}", bindContext.getDn() );
         }
 
         // ---- extract password from JNDI environment
-        byte[] credentials = opContext.getCredentials();
+        byte[] credentials = bindContext.getCredentials();
 
-        LdapPrincipal principal = getStoredPassword( opContext );
+        LdapPrincipal principal = getStoredPassword( bindContext );
 
         // Get the stored password, either from cache or from backend
         byte[] storedPassword = principal.getUserPassword();
@@ -289,7 +289,7 @@ public class SimpleAuthenticator extends
         {
             if ( IS_DEBUG )
             {
-                LOG.debug( "{} Authenticated", opContext.getDn() );
+                LOG.debug( "{} Authenticated", bindContext.getDn() );
             }
 
             return principal;
@@ -318,7 +318,7 @@ public class SimpleAuthenticator extends
             {
                 if ( IS_DEBUG )
                 {
-                    LOG.debug( "{} Authenticated", opContext.getDn() );
+                    LOG.debug( "{} Authenticated", bindContext.getDn() );
                 }
 
                 return principal;
@@ -326,7 +326,7 @@ public class SimpleAuthenticator extends
             else
             {
                 // Bad password ...
-                String message = I18n.err( I18n.ERR_230, opContext.getDn().getName() );
+                String message = I18n.err( I18n.ERR_230, bindContext.getDn().getName() );
                 LOG.info( message );
                 throw new LdapAuthenticationException( message );
             }
@@ -334,7 +334,7 @@ public class SimpleAuthenticator extends
         else
         {
             // Bad password ...
-            String message = I18n.err( I18n.ERR_230, opContext.getDn().getName() );
+            String message = I18n.err( I18n.ERR_230, bindContext.getDn().getName() );
             LOG.info( message );
             throw new LdapAuthenticationException( message );
         }
@@ -580,11 +580,11 @@ public class SimpleAuthenticator extends
 
     /**
      * Local function which request the password from the backend
-     * @param principalDn the principal to lookup
+     * @param bindContext the Bind operation context
      * @return the credentials from the backend
      * @throws Exception if there are problems accessing backend
      */
-    private byte[] lookupUserPassword( BindOperationContext opContext ) throws LdapAuthenticationException
+    private byte[] lookupUserPassword( BindOperationContext bindContext ) throws LdapAuthenticationException
     {
         // ---- lookup the principal entry's userPassword attribute
         Entry userEntry;
@@ -594,18 +594,18 @@ public class SimpleAuthenticator extends
             /*
              * NOTE: at this point the BindOperationContext does not has a 
              * null session since the user has not yet authenticated so we
              * cannot use opContext.lookup() yet.  This is a very special
              * case where we cannot rely on the opContext to perform a new
              * sub operation.
              */
             LookupOperationContext lookupContext = new LookupOperationContext( getDirectoryService().getAdminSession(),
-                opContext.getDn() );
+                bindContext.getDn() );
             lookupContext.setByPassed( USERLOOKUP_BYPASS );
             userEntry = getDirectoryService().getOperationManager().lookup( lookupContext );
 
             if ( userEntry == null )
             {
-                DN dn = opContext.getDn();
+                DN dn = bindContext.getDn();
                 String upDn = ( dn == null ? "" : dn.getName() );
 
                 throw new LdapAuthenticationException( I18n.err( I18n.ERR_231, upDn ) );
@@ -594,18 +594,18 @@ public class SimpleAuthenticator extends
              * NOTE: at this point the BindOperationContext does not has a 
              * null session since the user has not yet authenticated so we
-             * cannot use opContext.lookup() yet.  This is a very special
-             * case where we cannot rely on the opContext to perform a new
+             * cannot use lookup() yet.  This is a very special
+             * case where we cannot rely on the bindContext to perform a new
              * sub operation.
              */

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/StrongAuthenticator.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/StrongAuthenticator.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================